## ---- include = FALSE----------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ---- eval = FALSE-------------------------------------------------------
#  install.packages(c('changepoint', 'trend'))

## ---- eval = FALSE-------------------------------------------------------
#  path_to_file <- "C:/Non-stationarity/nonstat_1.0.0.tar.gz"

## ---- eval = FALSE-------------------------------------------------------
#  install.packages(path_to_file, repos = NULL, type="source")

## ----setup---------------------------------------------------------------
library(nonstat)

## ------------------------------------------------------------------------
folder <- "C:/Non-stationarity/Data"

## ------------------------------------------------------------------------
folder <- "C:/Non-stationarity/Data"
MK.test(folder, sig.level = 5)


## ------------------------------------------------------------------------
folder <- "C:/Non-stationarity/Data"
Pettitt.test(folder, sig.level = 5)


## ------------------------------------------------------------------------
folder <- "C:/Non-stationarity/Data"
PELT.test(folder)


## ------------------------------------------------------------------------
# Set up data to use as inputs to the fit.time function
dist <- "GEV"
folder <- "C:/Non-stationarity/Data"
RPs <- c(2, 10, 20, 50, 100)
CI <- 90
# Run the fitting function, saving the outputs to an object called 'GEVfits'.
GEVfits <- fit.time(dist, folder, RPs, CI)

## ---- eval=FALSE---------------------------------------------------------
#  # Save fitting results as a .RDS file
#  saveRDS(GEVfits, "Outputs/Time covariate only/GEV fits from fit time function.RDS")
#  # To read this back into R at a later date:
#  GEVfits <- readRDS("Outputs/Time covariate only/GEV fits from fit time function.RDS")

## ------------------------------------------------------------------------
# Plot results from one of the fitted models
# Set up data to use as inputs to the plot.selected.distributions function
folder <- "C:/Non-stationarity/Data"  # this does not need to be run if 'folder' is
                                      # already in your R environment from a previous step 
gauge <- "24004"
type <- "Varying location and scale"  # choose from 'Varying location', 
                                      # 'Varying scale' and 'Varying location and scale'
fitResults <- GEVfits
RPs <- c(2, 10, 20, 50, 100)
CI.RP <- 100  # return period for which a confidence interval is required
CI <- 90  # set to calculate 90% confidence interval
# Run the function
plot.selected.distributions(folder, gauge, type, fitResults, RPs, CI.RP, CI)

# Plot results from all of the fitted models
# Set up data to use as inputs to the plot.all function
folder <- "C:/Non-stationarity/Data"
gauge <- "24004"
fit.results <- GEVfits
RPs <- c(2, 10, 20, 50, 100)  # return periods to plot
# Run the function
plot.all(folder, gauge, fit.results, RPs)
# Note that the names of the input data do not have to match the names of the 
# function arguments. Here, fit.results is being used as an input to the fitResults 
# parameter. This could also be included as fitResults = fit.results, rather than 
# just fit.results. Specifying the argument like this would be required if the 
# arguments were given in the wrong order in the function, e.g. 
# plot.all(fitResults = fit.results, folder = folder, RPs = RPs, gauge = gauge).
# This would also work.

## ---- eval=FALSE---------------------------------------------------------
#  # Example of looping through gauges for plotting
#  
#  # Set parameters
#  dist <- "GEV"
#  folder <- "C:/Non-stationarity/Data"
#  RPs <- c(2, 10, 20, 50, 100)
#  CI <- 90
#  CI.RP <- 100
#  type <- "Varying location"
#  
#  # Fit models
#  GEVfits <- fit.time(dist, folder, RPs, CI)
#  fitResultsGEV <- GEVfits
#  
#  # List gauges to loop through
#  # The following line of code lists all .AM files in your 'Inputs' folder
#  gauges <- list.files(paste0(folder, "/Inputs"), pattern = ".AM", full.names = TRUE)
#  
#  # Read in the metadata file in your 'Inputs' folder
#  metadata <- read.csv(paste0(folder, "/Inputs/Gauge_metadata.csv"),
#                         stringsAsFactors = FALSE)
#  
#  # Loop through gauges
#  for (i in 1:length(gauges)){
#  
#    print(gauges[i])
#  
#    # Pre-process the data to extract the gauge number from within the .AM file
#    # (rather than from the file name). The former has been used in the analysis.
#    # This function is an internal function of the package and hence is not
#    # documented in this guidance, however there is a help file available.
#    preprocessedData <- import.preprocess.data(gauges[i], metadata = metadata)
#  
#    # If pre-processing has not produced an error then plot results
#    if (!is.null(preprocessedData$res)){
#  
#      gauge <- preprocessedData$res$gaugeNumber  # extract number of gauge to plot
#  
#      plot.selected.distributions(folder, gauge, type, fitResultsGEV, RPs, CI.RP, CI)
#  
#      plot.all(folder, gauge, fitResultsGEV, RPs)
#  
#    }
#  
#  }
#  

## ------------------------------------------------------------------------
# Fit models using physical covariates
folder <- "C:/Non-stationarity/Data"
dist <- "GEV"
# Run function and save outputs to an object named 'physCovModelFits'
physCovModelFits <- fit.phys.cov(dist, folder, detrend.cov = "ScaledWaterYearIndex", 
                                 option = 2, best_fit_method = "BIC")

# Obtain return levels based on one of the fitted models
# Set inputs
gauge <- "24004"
RPs <- c(2, 10, 20, 50, 100)
CI <- 90
# Run function
res.phys.cov(folder, physCovModelFits, gauge, RPs, CI, model_type = "Best", 
             locFit = NULL, scaleFit = NULL, present_day = TRUE)

## ---- eval = FALSE-------------------------------------------------------
#  # Setup -------------------------------------------------------------------
#  # Install package dependencies
#  install.packages(c('changepoint', 'trend'))
#  
#  # Install the nonstat package from saved location
#  path_to_file <- "C:/Non-stationarity/nonstat_1.0.0.tar.gz"
#  install.packages(path_to_file, repos = NULL, type="source")
#  
#  # Load the nonstat package
#  library(nonstat)
#  
#  # Set the path to the folder containing the 'Inputs' and 'Outputs' folders
#  folder <- "C:/Non-stationarity/Data"
#  
#  # Trend testing -----------------------------------------------------------
#  MK.test(folder, sig.level = 5)
#  Pettitt.test(folder, sig.level = 5)
#  PELT.test(folder)
#  
#  # Flood frequency analysis (time only as a covariate) ---------------------
#  
#  # Run the fitting function
#  dist <- "GEV"
#  RPs <- c(2, 10, 20, 50, 100)
#  CI <- 90  # set the confidence interval to be 90%
#  GEVfits <- fit.time(dist, folder, RPs, CI)
#  
#  # Run the plotting functions
#  gauge <- "24004"
#  type <- "Varying location and scale"
#  fit.results <- GEVfits
#  RPs <- c(20, 50, 100)  # return periods to plot
#  CI.RP <- 100  # return period for confidence interval plot
#  plot.selected.distributions(folder, gauge, type, fit.results, RPs, CI.RP, CI)
#  
#  RPs <- c(2, 10, 20, 50, 100) # return periods to plot
#  plot.all(folder, gauge, fit.results, RPs)
#  
#  # Flood frequency analysis (physical covariates) --------------------------
#  
#  # Run the fitting function
#  detrend.cov <- "ScaledWaterYearIndex"
#  option <- 2
#  best_fit_method <- "BIC"
#  physCovModelFits <- fit.phys.cov(dist, folder, detrend.cov, option, best_fit_method)
#  
#  # Obtain return levels based on one of the fitted models
#  gauge <- "24004"
#  RPs <- c(2, 10, 20, 50, 100)
#  res.phys.cov(folder, physCovModelFits, gauge, RPs, CI, model_type = "Best",
#               locFit = NULL, scaleFit = NULL, present_day = TRUE)
#  

