% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Run_physical_covariates_functions.R
\name{fit.phys.cov}
\alias{fit.phys.cov}
\title{fit.phys.cov}
\usage{
fit.phys.cov(dist, folder, detrend.cov = "ScaledWaterYearIndex",
  option = 2, best_fit_method = "BIC")
}
\arguments{
\item{dist}{string of the distribution to use to fit models using physical covariates. Must be either "GEV" or "GLO".}

\item{folder}{string containing a path to a folder containing two sub-folders called 'Inputs' and 'Outputs'. 'Inputs' must contain one file per gauge containing annual maximum data. Data should be .AM files.}

\item{detrend.cov}{optional string. If included (i.e. not NULL), the other covariates are detrended based on the covariate in this string, usually time (represented by “ScaledWaterYearIndex” in this function). This is recommended for models where a physical covariate and time may both be included in the location or scale parameter (options 1 and 2 below). The default is “ScaledWaterYearIndex”. This can be changed to NULL if you do not wish to detrend the covariate data.}

\item{option}{optional numeric integer - must be 1, 2 (default) or 3. Option 1 fits models using all possible combinations of covariates, option 2 fits models using combinations which only include one physical covariate and/or time, and option 3 fits models using combinations which include one covariate at a time in the location and/or scale parameter.}

\item{best_fit_method}{optional string. Method of automatically selecting a best fit model that can be used in the next step if desired. Must be "AIC" or "BIC" (default).}
}
\value{
A list containing information for all gauges analysed is returned from the function and can be accessed if the outputs have been saved to a named object (as in the examples below). For each gauge, the following information is saved: dist (distribution used - taken from input argument), model_fits (described below), all_data_raw (the data used in the model fitting - not detrended), gaugeName (name of the gauge) and detrend.cov (the string from the input argument). Most of these are saved for use in the next step. The information is also automatically saved as a .RDS file for each gauge separately, for reference purposes only.

The model_fits element is another list containing the following information: best_model (details of the best fitting model selected based on AIC or BIC, as specified by the user), best_model_formula (details of the formula used to fit best_model), stat_model (details of the fitted stationary model) and all_models_metadata (a metadata file associated with fitting models to all combinations of covariates selected by the user). The latter is also written out as a .csv file.
}
\description{
The fit.phys.cov function fits a stationary and multiple non-stationary GEV or GLO distributions to AMAX flow
data, using various combinations of physical covariates supplied by the user (a maximum of seven physical
covariates must be supplied). The user can then use the information returned about each model to decide which
model to use for estimating return levels (flows) for their required return periods.
}
\examples{
folder <- "C:/Non-stationarity/Data"
dist <- "GEV"
# Run without detrending the covariate data
physCovModelFits <- fit.phys.cov(dist, folder, detrend.cov = NULL, option = 3, best_fit_method = "BIC")
# Run with detrending the covariate data based on the time covariate (i.e. "ScaledWaterYearIndex", the
# automatically-generated centred and scaled index of water year)
physCovModelFits <- fit.phys.cov(dist, folder, detrend.cov = "ScaledWaterYearIndex", option = 2, best_fit_method = "BIC")
}
