% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit.time.R
\name{fit.time}
\alias{fit.time}
\title{fit.time}
\usage{
fit.time(dist, folder, RPs, CI = 90)
}
\arguments{
\item{dist}{string of the distribution to use in the fitting. Must be either "GEV" or "GLO".}

\item{folder}{string containing a path to a folder containing two sub-folders called 'Inputs' and 'Outputs'. 'Inputs' must contain one file per gauge containing annual maximum data. Data should be .AM files.}

\item{RPs}{numeric vector of return periods for which frequency analysis is required.}

\item{CI}{numeric value giving the required confidence interval as a percentage for the results from the flood frequency analysis (e.g. '90' for 90\% is the default value).}
}
\value{
Multiple .csv files are written out: one contains the parameters from the distribution fitting for all gauges, and there is one for each gauge containing the flows from the flood frequency analysis.  The remaining files contain warning and error information.

A list containing the data used in the analysis, the fitted distributions and the flood frequency results is also returned (but not automatically saved). The information can be accessed by saving the output from running the function to an object in R. The key to the distributions is as follows: stationary fitting = fit.stat, varying location = fit.var.loc, varying scale = fit.var.scale and varying both location and scale = fit.var.loc.scale.

Diagnostic plots (P-P and Q-Q) are also returned in a range of .png files.
}
\description{
fit.time fits stationary and non-stationary GEV or GLO distributions to AMAX flow data for all gauges provided by the user
in an ‘Inputs’ folder. This code is based on the 'texmex' package. The three non-stationary models have a varying location parameter, a varying scale parameter and
varying both location and scale parameters. The parameters vary with a covariate. This function uses time (an index of
water year, centred and scaled) as a covariate and automatically calculates a value for the covariate to associate with each
AMAX flow in the input data for the non-stationary distribution fitting, i.e. the user does not need to supply the time covariate.
Parameters of the fitted distributions and the results from frequency analysis are automatically written out to .csv files
in the 'Outputs/Time covariate models' folder.
}
\examples{
# Set the inputs to the function
dist <- "GEV"
folder <- "C:/Non-stationarity/Data"  # this folder contains sub-folders called 'Inputs' and 'Outputs'
RPs <- c(2, 10, 20, 50, 100)  # set required return periods to be 2, 10, 20, 50 and 100-year
CI <- 90  # set the confidence interval to be 90\%
# Run the function
GEVfits <- fit.time(dist, folder, RPs, CI)  # returns a list containing the data used, the fitted distributions and the frequency analysis results
# Save output to a .RDS file if desired
saveRDS(GEVfits, "Outputs/Time covariate models/GEV fits from fit time function.RDS")
}
