% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Plotting_functions.R
\name{plot.selected.distributions}
\alias{plot.selected.distributions}
\title{plot.selected.distributions}
\usage{
plot.selected.distributions(folder, gauge, type, fitResults, RPs, CI.RP,
  CI = 90, plotTitle = NULL)
}
\arguments{
\item{folder}{string containing a path to a folder containing two sub-folders called 'Inputs' and 'Outputs'.}

\item{gauge}{string of the gauge number to plot. Gauge must have been analysed in the 'fit.time' function.}

\item{type}{the type of non-stationary distribution to plot. Choose from 'Varying location', 'Varying scale' and 'Varying location and scale'.}

\item{fitResults}{the output from the fitting function fit.time. This could either be from a saved location or may already be in the R environment if fit.time has just been run and the outputs saved to a named object.}

\item{RPs}{vector of return periods to plot. There must be a maximum of five selected.}

\item{CI.RP}{numeric (single). Return period for which a confidence interval is to be plotted. Must be in RPs.}

\item{CI}{numeric (single). The required confidence interval as a percentage to plot for the frequency analysis results from the distribution fitting, e.g. ‘90’ for 90\% is the default.}

\item{plotTitle}{optional parameter. String containing title for output plot if you wish to change the automatically-generated title. To split a title over two lines use ‘\\n’ where you want the line break to be.}
}
\value{
A .png file containing two plots is returned. The first shows the results from the fitted stationary and one user-selected non-stationary distribution for specified return periods. The second shows confidence intervals for one specified return period.
}
\description{
This function plots the frequency analysis results from the fitted stationary distribution and one of the fitted non-stationary
distributions selected by the user (e.g. the best fitting non-stationary model based on likelihood ratio testing)
for one user-selected gauge using the outputs from fit.time for up to five return periods.
It also plots the confidence interval for one return period on a second plot. These plots will be automatically
written out to a .png file in the 'Outputs/Time covariate models' folder.
}
\examples{
# Set the inputs to the function
folder <- "C:/Non-stationarity/Data"
gauge <- "24004"
type <- "Varying location"  # select a non-stationary distribution
fit.results <- readRDS("Outputs/Time covariate models/GEV fits from fit time function.RDS") # if saved the output from running the fit.time function OR
fit.results <- GEVfits  # if the output from the fit.time function is still in the R environment
RPs <- c(20, 50, 100)  # return periods to plot
CI.RP <- 100  # return period for confidence interval plot
CI <- 90  # set the confidence interval to be 90\%
plot.selected.distributions(folder, gauge, type, fit.results, RPs, CI.RP, CI)
}
