% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Run_physical_covariates_functions.R
\name{res.phys.cov}
\alias{res.phys.cov}
\title{res.phys.cov}
\usage{
res.phys.cov(folder, physCovModelFits, gauge, RPs, CI = 90,
  model_type = "Best", locFit = NULL, scaleFit = NULL, present_day)
}
\arguments{
\item{folder}{string containing a path to a folder containing two sub-folders called 'Inputs' and 'Outputs'. 'Inputs' must contain one file per gauge containing annual maximum data. Data should be .AM files.}

\item{physCovModelFits}{output from the fit.phys.cov function}

\item{gauge}{string of the number of the gauge to analyse. Must have been used in the fit.phys.cov function and must match the number in the fitting information .csv file output from the fit.phys.cov function (so if the number has been edited then it should be the edited number, e.g. 24004x rather than 24004).}

\item{RPs}{numeric vector of return periods for which frequency analysis is required. A maximum of eight return periods can be plotted in the 'model results' plot - if more are listed here then only the first eight will be selected for the plot. All return periods will be used for the frequency analysis and for the 'encounter probability' plot.}

\item{CI}{numeric value. Confidence interval to be calculated for results as a percentage, e.g. ‘90’ for 90\% confidence interval is the default.}

\item{model_type}{string of "Best" or "User". Select whether to use the best fit model based on AIC/BIC or a user-selected model to calculate return levels (and then plot).}

\item{locFit}{string only required if model_type = "User". locFit is the regression equation of covariates to include in the location parameter (copy from 'fitting information (physical covariates)' .csv file output by the fit.phys.cov function), e.g. locFit = "~ 1 + NAO_SON + ScaledWaterYearIndex".}

\item{scaleFit}{string only required if model_type = "User". scaleFit is the regression equation of covariates to include in the scale parameter (copy from 'fitting information (physical covariates)' .csv file output by the fit.phys.cov function), e.g. scaleFit = "~ 1 + ScaledWaterYearIndex".}

\item{present_day}{logical - set to TRUE to calculate the present-day marginal return level as well as the marginal return level, otherwise set to FALSE. This can only be TRUE if time ("ScaledWaterYearIndex") is included as a covariate in the selected model.}
}
\value{
A .RDS file is returned which contains information relating to the analysis for the gauge (from the model used to estimate return levels, to the results of the frequency analysis). This can be opened in R and referred to at a later date if required. Much of the information is also written out in .csv files.

A range of .csv files are also returned which contain information about the formula of the non-stationary model used, to the conditional and marginal return levels (plus present-day marginal return levels, if selected) from the non-stationary model and the return levels from the stationary model.

Three plots are also written out as .png files. The first ('correlation plot') is of flow plotted against all covariates (detrended if this option was selected). The second ('model results plot') is of flow plotted against conditional return levels from the non-stationary model and stationary return levels from the stationary model for the observed period. The third ('encounter probability plot') is an encounter probability plot showing the marginal and stationary results.
}
\description{
The res.phys.cov function uses one of the fitted non-stationary models from the 'fit.phys.cov' function
to estimate conditional and marginal return levels (and present-day marginal return levels if required).
Stationary return levels are estimated based on the fitted stationary model.
This function also outputs plots of the results.
}
\examples{
folder <- "C:/Non-stationarity/Data"
physCovModelFits <- physCovModelFits  # output from running the fit.phys.cov function
gauge <- "24004"
RPs <- c(2, 10, 20, 50, 100)
CI <- 90
# Using the best model based on AIC or BIC (as selected in fit.phys.cov)
res.phys.cov(folder, physCovModelFits, gauge, RPs, CI, model_type = "Best", locFit = NULL, scaleFit = NULL, present_day = TRUE)
# Using a user-selected model
res.phys.cov(folder, physCovModelFits, gauge, RPs, CI, model_type = "User", locFit = "~ 1 + Rain_WY_mean + ScaledWaterYearIndex", scaleFit = "~ 1 + ScaledWaterYearIndex", present_day = TRUE)
}
